@@ -62,6 +62,22 @@ typedef enum
     SCAN_MODE_LINEART
 } ScanMode;
 
+typedef enum
+{
+    SCAN_SINGLE,
+    SCAN_ADF_FRONT,
+    SCAN_ADF_BACK,
+    SCAN_ADF_BOTH
+} ScanType;
+
+typedef struct
+{
+    gint dpi;
+    ScanMode scan_mode;
+    gint depth;
+    ScanType type;
+    gint paper_width, paper_height;
+} ScanOptions;
 
 typedef struct ScannerPrivate ScannerPrivate;
 
@@ -99,8 +115,7 @@ void scanner_redetect (Scanner *scanner);
 
 gboolean scanner_is_scanning (Scanner *scanner);
 
-void scanner_scan (Scanner *scanner, const char *device,
-                   gint dpi, ScanMode scan_mode, gint depth, gboolean multi_page);
+void scanner_scan (Scanner *scanner, const char *device, ScanOptions *options);
 
 void scanner_cancel (Scanner *scanner);
 
